summaryrefslogtreecommitdiffstats
path: root/src/render/materialsystem/qmaterial.cpp
diff options
context:
space:
mode:
authorColin Ogilvie <colin.ogilvie@kdab.com>2016-05-24 12:09:17 +0100
committerSean Harmer <sean.harmer@kdab.com>2016-05-25 19:52:10 +0000
commit78ce47be07d077f26a1542c8cd84b8f788834e1a (patch)
treef7a1385dd8542c7704cfb500ee12b6d2d07de521 /src/render/materialsystem/qmaterial.cpp
parent587f6cf2d7cd9748703036556be000866edde9d7 (diff)
Start of Skeletal Doc for render-materialsystem
Task-number: QTBUG-46037 Change-Id: I8f2a2ed2068cbe7a4a9265a56c99845a0322df2c Reviewed-by: Sean Harmer <sean.harmer@kdab.com>
Diffstat (limited to 'src/render/materialsystem/qmaterial.cpp')
-rw-r--r--src/render/materialsystem/qmaterial.cpp28
1 files changed, 25 insertions, 3 deletions
diff --git a/src/render/materialsystem/qmaterial.cpp b/src/render/materialsystem/qmaterial.cpp
index fa4955017..b116b57dd 100644
--- a/src/render/materialsystem/qmaterial.cpp
+++ b/src/render/materialsystem/qmaterial.cpp
@@ -52,19 +52,19 @@
* \instantiates Qt3DRender::QMaterial
* \inqmlmodule Qt3D.Render
* \brief Non-creatable abstract base for materials.
+ * \inherits Component
*/
/*!
* \class Qt3DRender::QMaterial
* \inmodule Qt3DRender
*
- * \inherits Component
*
* \brief Provides an abstract class that should be the base of all
* Material component classes in a scene.
*
* QAbstractMaterial provide a way to specify the rendering of an Entity.
* Any aspect can define its own subclass of QAbstractMaterial so that a
* Material can be used to describe a visual element; for example, the way
* sound should reflect off an element, the temperature of a surface,
* and so on.
@@ -88,6 +88,10 @@ QMaterialPrivate::~QMaterialPrivate()
{
}
+/*!
+ \fn Qt3DRender::QMaterial::QMaterial(Qt3DCore::QNode *parent)
+ Constructs a new QMaterial with the specified \a parent.
+ */
QMaterial::QMaterial(QNode *parent)
: QComponent(*new QMaterialPrivate, parent)
{
@@ -105,6 +109,15 @@ QMaterial::QMaterial(QMaterialPrivate &dd, QNode *parent)
}
/*!
+ \qmlproperty QEffect Qt3D.Render::Material::effect
+ Specifies the effect to be used with the material
+*/
+
+/*!
+ \property Qt3DRender::QMaterial::effect
+ Specifies the effect to be used with the material
+ */
+/*!
* Sets the \a effect to be used with the Material.
*/
void QMaterial::setEffect(QEffect *effect)
@@ -140,6 +153,9 @@ QEffect *QMaterial::effect() const
return d->m_effect;
}
+/*!
+ * Add a parameter to the Material.
+ */
void QMaterial::addParameter(QParameter *parameter)
{
Q_ASSERT(parameter);
@@ -165,6 +181,9 @@ void QMaterial::addParameter(QParameter *parameter)
}
}
+/*!
+ * Remove a parameter from the Material.
+ */
void QMaterial::removeParameter(QParameter *parameter)
{
Q_ASSERT(parameter);
@@ -177,6 +196,9 @@ void QMaterial::removeParameter(QParameter *parameter)
d->m_parameters.removeOne(parameter);
}
+/*!
+ * Returns a vector of the materials current parameters
+ */
QVector<QParameter *> QMaterial::parameters() const
{
Q_D(const QMaterial);
@@ -52,19 +52,19 @@
* Material component classes in a scene.
*
- * QAbstractMaterial provide a way to specify the rendering of an Entity.
- * Any aspect can define its own subclass of QAbstractMaterial so that a
+ * QMaterial provides a way to specify the rendering of an Entity.
+ * Any aspect can define its own subclass of QMaterial so that a
* Material can be used to describe a visual element; for example, the way
* sound should reflect off an element, the temperature of a surface,